import * as React from "react";
import { useState } from 'react'
import {
  FolderRegular,
  DocumentRegular,
  DocumentPdfRegular,
  VideoRegular,
  ChevronDown16Filled,
  TextField16Regular,
  Calendar16Regular,
  SelectAllOn16Regular,
  MoreHorizontal16Filled,
  CommentAdd16Regular
} from "@fluentui/react-icons";
import {
  PresenceBadgeStatus,
  Avatar,
  DataGridBody,
  DataGridRow,
  DataGrid,
  DataGridHeader,
  DataGridHeaderCell,
  DataGridCell,
  TableCellLayout,
  createTableColumn,
  Button,
  Menu,
  MenuTrigger,
  MenuList,
  MenuItem,
  MenuPopover,
  Text
} from "@fluentui/react-components";


const items = [
  {
    姓名: { label: "陈丹", icon: <DocumentRegular /> },
    性别: { label: "女", status: "available" },
    年龄: { label: "18岁", timestamp: 1 },
    最后在线时间: { label: "2024/11/6 13:50" },
  },
  {
    姓名: { label: "蔡青松", icon: <FolderRegular /> },
    性别: { label: "男", status: "busy" },
    年龄: { label: "30岁", timestamp: 2 },
    最后在线时间: { label: "2024/11/6 13:50" },
  },
  {
    姓名: { label: "杨东明", icon: <VideoRegular /> },
    性别: { label: "男", status: "away" },
    年龄: { label: "25岁", timestamp: 2 },
    最后在线时间: { label: "2024/11/6 13:50" },
  },
  {
    姓名: { label: "吴瑞强", icon: <DocumentPdfRegular /> },
    性别: { label: "男", status: "offline" },
    年龄: { label: "25岁", timestamp: 3 },
    最后在线时间: { label: "2024/11/6 13:50" },
  },
];


const List = () => {
  const defaultSelectedItems = React.useMemo(() => new Set([1]), []);
  const [showButton, setShowButton] = useState(false);


  return (
    <DataGrid
      items={items}
      columns={[
        createTableColumn({
          columnId: "姓名",
          compare: (a, b) => {
            return a.姓名.label.localeCompare(b.姓名.label);
          },
          renderHeaderCell: () => {
            return (
              <TableCellLayout
                media={<TextField16Regular />}
              >
                姓名
                <Menu>
                  <MenuTrigger disableButtonEnhancement>
                    <Button appearance="subtle" icon={<ChevronDown16Filled />}></Button>
                  </MenuTrigger>

                  <MenuPopover>
                    <MenuList>
                      <MenuItem>New </MenuItem>
                      <MenuItem>New Window</MenuItem>
                      <MenuItem disabled>Open File</MenuItem>
                      <MenuItem>Open Folder</MenuItem>
                    </MenuList>
                  </MenuPopover>
                </Menu>
              </TableCellLayout>
            );
          },
          renderCell: (item) => {

            const handleMouseEnter = () => {
              setShowButton(true);
            };

            const handleMouseLeave = () => {
              setShowButton(false);
            };
            return (
              <div style={{ width: "100%", display: "flex", justifyContent: "space-between", alignItems: "center" }}>
                <span>{item.姓名.label}</span>
                <div
                  onMouseEnter={handleMouseEnter}
                  onMouseLeave={handleMouseLeave}
                >
                  {showButton && (
                    <Button appearance="subtle" icon={<MoreHorizontal16Filled />}></Button>
                  )}
                  {/* <Button appearance="subtle" icon={<MoreHorizontal16Filled />}></Button> */}
                  {/* <Button appearance="subtle" icon={<CommentAdd16Regular />}></Button> */}
                </div>
              </div>
            );
          },
        }),
        createTableColumn({
          columnId: "性别",
          compare: (a, b) => {
            return a.性别.label.localeCompare(b.性别.label);
          },
          renderHeaderCell: () => {
            return (
              <TableCellLayout
                media={<SelectAllOn16Regular />}
              >
                性别
                <Menu>
                  <MenuTrigger disableButtonEnhancement>
                    <Button appearance="subtle" icon={<ChevronDown16Filled />}></Button>
                  </MenuTrigger>

                  <MenuPopover>
                    <MenuList>
                      <MenuItem>New </MenuItem>
                      <MenuItem>New Window</MenuItem>
                      <MenuItem disabled>Open File</MenuItem>
                      <MenuItem>Open Folder</MenuItem>
                    </MenuList>
                  </MenuPopover>
                </Menu>
              </TableCellLayout>
            );
          },
          renderCell: (item) => {
            return item.性别.label;
          },
        }),
        createTableColumn({
          columnId: "年龄",
          compare: (a, b) => {
            return a.年龄.timestamp - b.年龄.timestamp;
          },
          renderHeaderCell: () => {
            return (
              <TableCellLayout
                media={<TextField16Regular />}
              >
                年龄
                <Menu>
                  <MenuTrigger disableButtonEnhancement>
                    <Button appearance="subtle" icon={<ChevronDown16Filled />}></Button>
                  </MenuTrigger>

                  <MenuPopover>
                    <MenuList>
                      <MenuItem>New </MenuItem>
                      <MenuItem>New Window</MenuItem>
                      <MenuItem disabled>Open File</MenuItem>
                      <MenuItem>Open Folder</MenuItem>
                    </MenuList>
                  </MenuPopover>
                </Menu>
              </TableCellLayout>
            );
          },

          renderCell: (item) => {
            return item.年龄.label;
          },
        }),
        createTableColumn({
          columnId: "最后在线时间",
          compare: (a, b) => {
            return a.最后在线时间.label.localeCompare(b.最后在线时间.label);
          },
          renderHeaderCell: () => {
            return (
              <TableCellLayout
                media={<Calendar16Regular />}
              >
                最后在线时间
                <Menu>
                  <MenuTrigger disableButtonEnhancement>
                    <Button appearance="subtle" icon={<ChevronDown16Filled />}></Button>
                  </MenuTrigger>

                  <MenuPopover>
                    <MenuList>
                      <MenuItem>New </MenuItem>
                      <MenuItem>New Window</MenuItem>
                      <MenuItem disabled>Open File</MenuItem>
                      <MenuItem>Open Folder</MenuItem>
                    </MenuList>
                  </MenuPopover>
                </Menu>
              </TableCellLayout>
            );
          },
          renderCell: (item) => {
            return (
              <TableCellLayout media={item.最后在线时间.icon}>
                {item.最后在线时间.label}
              </TableCellLayout>
            );
          },
        }),
      ]}
      selectionMode="single"
      // sortable
      subtleSelection
      resizableColumns
      defaultSelectedItems={defaultSelectedItems}
      style={{ minWidth: "550px" }}
    >
      <DataGridHeader>
        <DataGridRow>
          {({ renderHeaderCell }) => (
            <DataGridHeaderCell>{renderHeaderCell()}</DataGridHeaderCell>
          )}
        </DataGridRow>
      </DataGridHeader>
      <DataGridBody>
        {({ item, rowId }) => (
          <DataGridRow
            key={rowId}
            selectionCell={{ radioIndicator: { "aria-label": "Select row" } }}
          >
            {({ renderCell }) => (
              <DataGridCell>{renderCell(item)}</DataGridCell>
            )}
          </DataGridRow>
        )}
      </DataGridBody>
    </DataGrid>
  );
};

export default List;